=== "pipx"

    To install with `pipx`, type:

    ```
    pipx install box-packager
    ```

    Alternatively, you can install the latest version directly from the GitHub repo.
    This is only recommended if you want the latest tweaks.
    For a production environment, please use the official releases.

    ```
    pipx install git+https://github.com/trappitsch/box.git
    ```

=== "rye"

    To install box as a `rye` tool, type:

    ```
    rye install box-packager
    ```

    Alternatively, you can install the latest version directly from the GitHub repo.
    This is only recommended if you want the latest tweaks.
    For a production environment, please use the official releases.

    ```
    rye install --git https://github.com/trappitsch/box.git box
    ```

=== "pip"

    We do not recommend installing `box` with `pip`,
    however, if have to do so for some reason,
    install it via:

    ```
    pip install box-packager
    ```

    Alternatively, you can install the latest version directly from the GitHub repo.
    This is only recommended if you want the latest tweaks.
    For a production environment, please use the official releases.

    ```
    pip install git+https://github.com/trappitsch/box.git
    ```
